@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class LogsConfig(AppConfig):
-    name = 'logs'
+    name = 'tamarin.logs'
